# Sphinx-generated HTML documentation is not suitable for packaging; see
# https://bugzilla.redhat.com/show_bug.cgi?id=2006555 for discussion.
#
# We can generate PDF documentation as a lesser substitute.
%bcond_without doc_pdf

%global srcname flask-socketio

Name:           python-%{srcname}
Version:        4.3.2
Release:        2%{?dist}
Summary:        Socket.IO integration for Flask applications

# Entire source is MIT, except docs/_themes/ which is BSD
License:        MIT
URL:            https://github.com/miguelgrinberg/Flask-SocketIO/
Source0:        %{url}/archive/v%{version}/Flask-SocketIO-%{version}.tar.gz

BuildArch:      noarch
 
BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros

# Documentation
%if %{with doc_pdf}
BuildRequires:  make
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3-sphinx-latex
BuildRequires:  latexmk
%endif

# Extra testing dependencies
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(coverage)

%global common_description %{expand:
Flask-SocketIO gives Flask applications access to low latency bi-directional
communications between the clients and the server. The client-side application
can use any of the SocketIO official clients libraries in Javascript, C++, Java
and Swift, or any compatible client to establish a permanent connection to the
server.}

%description %{common_description}


%generate_buildrequires
%pyproject_buildrequires -r


%package -n     python3-%{srcname}
Summary:        %{summary}
# Entire source is MIT, except docs/_themes/ which is BSD
License:        MIT and BSD

# This is the BSD-licensed portion. The package was retired upstream and in
# Fedora, and later versions of Flask-SocketIO do not require it, so we accept
# bundling as a temporary measure.
Provides:       bundled(python3dist(pallets-sphinx-themes))

%description -n python3-%{srcname} %{common_description}


%package        doc
Summary:        Documentation for %{name}

%description    doc %{common_description}


%prep
%autosetup -n Flask-SocketIO-%{version}

# Find executable files without shebang lines, and fix their permissions.
# https://github.com/miguelgrinberg/Flask-SocketIO/pull/1621
find . -type f -perm /0111 |
  while read -r fn
  do
    if ! head "${fn}" | grep -E '^#!' >/dev/null
    then
      chmod -v a-x "${fn}"
    fi
  done
# Fix “/usr/bin/env python” shebangs in the example
%py3_shebang_fix example


%build
%pyproject_wheel
%if %{with doc_pdf}
PYTHONPATH="${PWD}/src" %make_build -C docs latex SPHINXOPTS='%{?_smp_mflags}'
%make_build -C docs/_build/latex
%endif


%install
%pyproject_install
%pyproject_save_files flask_socketio


%check
# Test{AsyncServer,Client,Server}.test_logger are failing with:
#   AssertionError: 30 != 40
# This should be looked into more closely if it is not fixed in a later release.
#pytest -k 'not test_logger'
%pytest


%files -n python3-%{srcname} -f %{pyproject_files}
%license LICENSE


%files doc
%license LICENSE
%doc CHANGES.md
%doc README.md
%if %{with doc_pdf}
%doc docs/_build/latex/Flask-SocketIO.pdf
%endif
%doc example


%changelog
* Fri Oct 01 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 4.3.2-2
- Generate PDF instead of HTML Sphinx documentation

* Mon Jul 05 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 4.3.2-1
- Update to 4.3.2
- Near-total spec file rewrite
- Remove obsolete practices like python_provide macro and manual Requires
- Add documentation subpackage
- Use pytest as test runner
- Fix spurious executable permissions (upstream PR#748)

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 4.2.1-7
- Rebuilt for Python 3.10

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 4.2.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.2.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 4.2.1-4
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Dec 31 2019 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 4.2.1-2
- Use expand macro for description

* Sun Dec 22 2019 Mukundan Ragavan <nonamedotc@gmail.com> - 4.2.1-1
- Initial package.
